package org.krews.apollyon;

import com.eu.habbo.Emulator;
import com.eu.habbo.habbohotel.users.Habbo;
import com.eu.habbo.messages.PacketManager;
import com.eu.habbo.messages.incoming.Incoming;
import com.eu.habbo.messages.incoming.MessageHandler;
import com.eu.habbo.plugin.EventHandler;
import com.eu.habbo.plugin.EventListener;
import com.eu.habbo.plugin.HabboPlugin;
import com.eu.habbo.plugin.events.emulator.EmulatorLoadedEvent;
import gnu.trove.map.hash.THashMap;
import org.krews.apollyon.incoming.CameraPublishToWebEvent;
import org.krews.apollyon.incoming.CameraPurchaseEvent;
import org.krews.apollyon.incoming.CameraRoomPictureEvent;
import org.krews.apollyon.incoming.CameraRoomThumbnailEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.reflect.Field;


/**
 * Apollyon
 * The Official Camera Plugin for Morningstar. Credits to John, Beny, Ovflowd, and Alejandro
 *
 * @author Krews.org
 */

public class Main extends HabboPlugin implements EventListener {
    private static final Logger LOGGER = LoggerFactory.getLogger(Emulator.class);

    @Override
    public void onEnable() {
        Emulator.getPluginManager().registerEvents(this, this);

        if (Emulator.isReady && !Emulator.isShuttingDown) {
            this.onEmulatorLoadedEvent(null);
        }
    }

    @Override
    public boolean hasPermission(Habbo habbo, String string) {
        return false;
    }

    @Override
    public void onDisable() {
        try {
            // put the original packets back
            PacketManager packetManager = Emulator.getGameServer().getPacketManager();
            Field f = PacketManager.class.getDeclaredField("incoming");
            f.setAccessible(true);
            THashMap<Integer, Class<? extends MessageHandler>> incoming = (THashMap<Integer, Class<? extends MessageHandler>>) f.get(packetManager);
            incoming.remove(Incoming.renderRoomEvent, CameraRoomPictureEvent.class);
            incoming.remove(Incoming.publishPhotoEvent, CameraPublishToWebEvent.class);
            incoming.remove(Incoming.purchasePhotoEvent, CameraPurchaseEvent.class);
            incoming.remove(Incoming.renderRoomThumbnailEvent, CameraRoomThumbnailEvent.class);
        } catch (Exception ex) {
            LOGGER.error("Apollyon failed to disable!");
            throw new RuntimeException(ex);
        }
    }

    @EventHandler
    public void onEmulatorLoadedEvent(EmulatorLoadedEvent e) {
        try {
            // Adds missing sqls if they are not found.
            Emulator.getConfig().register("camera.url", "http://yourdomain.com/swfdirectory/camera/");
            Emulator.getConfig().register("imager.location.output.camera", "C:\\yourdirectory\\swfdirectory\\camera\\");
            Emulator.getConfig().register("imager.location.output.thumbnail", "C:\\yourdirectory\\swfdirectory\\camera\\thumbnails\\thumbnail_");

            PacketManager packetManager = Emulator.getGameServer().getPacketManager();
            Field f = PacketManager.class.getDeclaredField("incoming");
            f.setAccessible(true);
            THashMap<Integer, Class<? extends MessageHandler>> incoming = (THashMap<Integer, Class<? extends MessageHandler>>) f.get(packetManager);

            // Removes the current arcturus handlers for these packets
            incoming.remove(Incoming.renderRoomEvent);
            incoming.remove(Incoming.publishPhotoEvent);
            incoming.remove(Incoming.purchasePhotoEvent);
            incoming.remove(Incoming.renderRoomThumbnailEvent);

            // Adds the PNGCamera Packet Handlers
            packetManager.registerHandler(Incoming.renderRoomEvent, CameraRoomPictureEvent.class);
            packetManager.registerHandler(Incoming.publishPhotoEvent, CameraPublishToWebEvent.class);
            packetManager.registerHandler(Incoming.purchasePhotoEvent, CameraPurchaseEvent.class);
            packetManager.registerHandler(Incoming.renderRoomThumbnailEvent, CameraRoomThumbnailEvent.class);

            // Send the message to the Emulator that PNGCamera has started.
            LOGGER.info("OFFICIAL PLUGIN - Apollyon has been loaded!");
        } catch (Exception ex) {
            LOGGER.error("Apollyon failed to load!");
            throw new RuntimeException(ex);
        }

    }

}
